#
# Spec file for oracleasm
#

# Macros
# This one is hardcoded because, well, it belongs there
%define _prefix /usr
# Because RPM is dumb
%define _unpackaged_files_terminate_build 0

# Turn on's and off's
%define buildup		1
%define buildsmp	0
%define buildhugemem	0
%define buildlargesmp	0
%define buildxenu	0

%ifarch i686
%define karch		i686
%define buildsmp	1
%define buildhugemem	1
%define buildxenu	1
%endif

%ifarch x86_64
%define karch		x86_64
%define buildsmp	1
%define buildlargesmp	1
%define buildxenu	1
%endif

%ifarch ia32e
%define karch		ia32e
%endif

%ifarch ia64
%define karch		ia64
%define buildlargesmp	1
%endif

%ifarch ppc64
%define karch		ppc64
%define buildlargesmp	1
%endif

%ifarch s390x
%define karch		s390x
%endif


# This must be changed to the minimum ABI compat kernel version expected
%define kver		2.6.9-55.0.21.0.1.EL

# The minimum -support package required for the kernel bits.
%define support_ver     2.0.0
# Minimum oracleasmlib version that supports positive ASM_ERR_NODEV.
%define min_enodev	2.0.1

Summary: The Oracle Automatic Storage Management library driver.
Name: oracleasm-%{kver}
Version: 2.0.5
Release: 1.el4
License: GPL
Group: System Environment/Kernel
Source: oracleasm-2.0.5.tar.gz
URL: http://oss.oracle.com/projects/oracleasm/
Distribution: Oracle
Vendor: Oracle Corporation
Packager: Joel Becker <joel.becker@oracle.com>
Provides: oracleasm = %{version}
AutoReqProv: no
Requires: kernel = %{kver}
Requires: oracleasm-support >= %{support_ver}
Conflicts: oracleasmlib < %{min_enodev}
BuildRequires: kernel-devel = %{kver}


BuildRoot: %{_tmppath}/oracleasm-%{PACKAGE_VERSION}-%{PACKAGE_RELEASE}-root


%description
Kernel driver for the Oracle Automatic Storage Management library.
This package is compiled for the default kernel.

%if %{buildsmp}
%package -n oracleasm-%{kver}smp
Summary: The Oracle Automatic Storage Management library driver for SMP systems.
Group: System Environment/Kernel
AutoReqProv: no
Provides: oracleasm = %{version}
Requires: kernel-smp = %{kver}
Requires: oracleasm-support >= %{support_ver}
Conflicts: oracleasmlib < %{min_enodev}
BuildRequires: kernel-smp-devel = %{kver}

%description -n oracleasm-%{kver}smp
Kernel driver for the Oracle Automatic Storage Management library.
This package is compiled for symmetric multiprocessor kernels.
%endif


%if %{buildhugemem}
%package -n oracleasm-%{kver}hugemem
Summary: The Oracle Automatic Storage Management library driver for NUMA systems.
Group: System Environment/Kernel
Provides: oracleasm = %{version}
AutoReqProv: no
Requires: kernel-hugemem = %{kver}
Requires: oracleasm-support >= %{support_ver}
Conflicts: oracleasmlib < %{min_enodev}
BuildRequires: kernel-hugemem-devel = %{kver}

%description -n oracleasm-%{kver}hugemem
Kernel driver for the Oracle Automatic Storage Management library.
This package is compiled for large memory SMP kernels.
%endif


%if %{buildlargesmp}
%package -n oracleasm-%{kver}largesmp
Summary: The Oracle Automatic Storage Management library driver for NUMA systems.
Group: System Environment/Kernel
Provides: oracleasm = %{version}
AutoReqProv: no
Requires: kernel-largesmp = %{kver}
Requires: oracleasm-support >= %{support_ver}
Conflicts: oracleasmlib < %{min_enodev}
BuildRequires: kernel-largesmp-devel = %{kver}

%description -n oracleasm-%{kver}largesmp
Kernel driver for the Oracle Automatic Storage Management library.
This package is compiled for large SMP kernels.
%endif

%if %{buildxenu}
%package -n oracleasm-%{kver}xenU
Summary: The Oracle Automatic Storage Management library driver for Xen DomU kernels.
Group: System Environment/Kernel
Provides: oracleasm = %{version}
AutoReqProv: no
Requires: kernel-xenU = %{kver}
Requires: oracleasm-support >= %{support_ver}
Conflicts: oracleasmlib < %{min_enodev}
BuildRequires: kernel-xenU-devel = %{kver}

%description -n oracleasm-%{kver}xenU
Kernel driver for the Oracle Automatic Storage Management library.
This package is compiled for Xen DomU kernels.
%endif


%prep
%setup -n oracleasm-%{version}


%build

local_configure()
{
	./configure					\
		--prefix=%{_prefix}			\
		--exec-prefix=%{_exec_prefix}		\
		--bindir=%{_bindir}			\
		--sbindir=%{_sbindir}			\
		--sysconfdir=%{_sysconfdir}		\
		--datadir=%{_datadir}			\
		--includedir=%{_includedir}		\
		--libdir=%{_libdir}			\
		--libexecdir=%{_libexecdir}		\
		--localstatedir=%{_localstatedir}	\
		--sharedstatedir=%{_sharedstatedir}	\
		--mandir=%{_mandir}			\
		--infodir=%{_infodir}			\
		--with-vendor=rhel4			\
		--with-vendorkernel="$1"
}

%if %{buildup}
local_configure "%{kver}"

make QUIET=1
make DESTDIR="$RPM_BUILD_ROOT" INSTALL_MOD_PATH='$(DESTDIR)' install 

# 2.6 kbuild can't do this install nicely
EXTRA_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}/extra"
INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}/kernel/drivers/addon/oracleasm"
mkdir -p "${INST_MODLIB}"
mv "${EXTRA_MODLIB}"/oracleasm.ko "${INST_MODLIB}/"

make clean
%endif

%if %{buildsmp}
local_configure "%{kver}smp"

make QUIET=1
make DESTDIR="$RPM_BUILD_ROOT" INSTALL_MOD_PATH='$(DESTDIR)' install 

# 2.6 kbuild can't do this install nicely
EXTRA_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}smp/extra"
INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}smp/kernel/drivers/addon/oracleasm"
mkdir -p "${INST_MODLIB}"
mv "${EXTRA_MODLIB}"/oracleasm.ko "${INST_MODLIB}/"

make clean
%endif

%if %{buildhugemem}
local_configure "%{kver}hugemem"

make QUIET=1
make DESTDIR="$RPM_BUILD_ROOT" INSTALL_MOD_PATH='$(DESTDIR)' install 

# 2.6 kbuild can't do this install nicely
EXTRA_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}hugemem/extra"
INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}hugemem/kernel/drivers/addon/oracleasm"
mkdir -p "${INST_MODLIB}"
mv "${EXTRA_MODLIB}"/oracleasm.ko "${INST_MODLIB}/"

make clean
%endif

%if %{buildlargesmp}
local_configure "%{kver}largesmp"

make QUIET=1
make DESTDIR="$RPM_BUILD_ROOT" INSTALL_MOD_PATH='$(DESTDIR)' install 

# 2.6 kbuild can't do this install nicely
EXTRA_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}largesmp/extra"
INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}largesmp/kernel/drivers/addon/oracleasm"
mkdir -p "${INST_MODLIB}"
mv "${EXTRA_MODLIB}"/oracleasm.ko "${INST_MODLIB}/"

make clean
%endif

%if %{buildxenu}
local_configure "%{kver}xenU"

make QUIET=1
make DESTDIR="$RPM_BUILD_ROOT" INSTALL_MOD_PATH='$(DESTDIR)' install

# 2.6 kbuild can't do this install nicely
EXTRA_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}xenU/extra"
INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}xenU/kernel/drivers/addon/oracleasm"
mkdir -p "${INST_MODLIB}"
mv "${EXTRA_MODLIB}"/oracleasm.ko "${INST_MODLIB}/"

make clean
%endif


%install



%clean
rm -rf "$RPM_BUILD_ROOT"



%if %{buildup}
%post -n oracleasm-%{kver}
depmod -ae %{kver}

%files -n oracleasm-%{kver}
%defattr(-,root,root)
/lib/modules/%{kver}/kernel/drivers/addon/oracleasm
%endif


%if %{buildsmp}
%post -n oracleasm-%{kver}smp
depmod -ae %{kver}smp

%files -n oracleasm-%{kver}smp
%defattr(-,root,root)
/lib/modules/%{kver}smp/kernel/drivers/addon/oracleasm
%endif


%if %{buildhugemem}
%post -n oracleasm-%{kver}hugemem
depmod -ae %{kver}hugemem

%files -n oracleasm-%{kver}hugemem
%defattr(-,root,root)
/lib/modules/%{kver}hugemem/kernel/drivers/addon/oracleasm
%endif

%if %{buildlargesmp}
%post -n oracleasm-%{kver}largesmp
depmod -ae %{kver}largesmp

%files -n oracleasm-%{kver}largesmp
%defattr(-,root,root)
/lib/modules/%{kver}largesmp/kernel/drivers/addon/oracleasm
%endif

%if %{buildxenu}
%post -n oracleasm-%{kver}xenU
depmod -ae %{kver}xenU

%files -n oracleasm-%{kver}xenU
%defattr(-,root,root)
/lib/modules/%{kver}xenU/kernel/drivers/addon/oracleasm
%endif


%changelog
* Fri Oct 26 2007 Sunil Mushran <sunil.mushran@oracle.com>
- Add xenU

* Thu May 25 2006 Joel Becker <joel.becker@oracle.com>
- Add largesmp

* Fri Feb 04 2005 Joel Becker <joel.becker@oracle.com>
- Make RHEL4 specfile.

* Tue Sep 21 2004 Joel Becker <joel.becker@oracle.com>
- Make SLES9 specfile.

* Tue Jan 13 2004 Joel Becker <joel.becker@oracle.com>
- Make kernel-only.

* Thu Nov 20 2003 Joel Becker <joel.becker@oracle.com>
- Add x86 and ia64 targets.

* Wed Nov 19 2003 Joel Becker <joel.becker@oracle.com>
- Make the UL SP3 changes.

* Wed Nov 12 2003 Joel Becker <joel.becker@oracle.com>
- Start the ASM rename.

* Thu Oct 30 2003 Joel Becker <joel.becker@oracle.com>
- Created EL3 version

* Mon Jun 23 2003 Joel Becker <joel.becker@oracle.com>
- Added osm-lib bits

* Fri Jun 20 2003 Joel Becker <joel.becker@oracle.com>
- Initial RPM

